class Admin::ProductsController < AdminController
  
  before_action :set_product, only: [:edit, :update, :destroy]

  def new
    @product = Product.new
    @subcategory = Subcategory.find(params[:subcategory_id])
    @category = @subcategory.category

    @type_calculations = []
    TypeCalculation.all.each do |type_calculation|
      @type_calculations << [type_calculation.name, type_calculation.id]
    end
  end

  def index
    @products = Product.where(subcategory_id: params[:subcategory_id])
  end

  def edit
    @product_block = ProductBlock.new
    @product_blocks = ProductBlock.where(product_id: @product.id).sort_by {|pb| [pb.size_z, pb.size] }
    @product_image = ProductImage.new
    @product_images = ProductImage.where(product_id: @product.id)
    @category = @product.subcategory.category
    @subcategory = @product.subcategory
    @type_calculation = TypeCalculation.find(@product.type_calculation_id).name
  end

  def create
    @product = Product.new(product_params)
    @product = set_attributes_languages(@product, ['name', 'description'])

    respond_to do |format|
      if @product.save
        format.html { redirect_to edit_admin_product_path(@product), notice: 'Product was successfully created.' }
      else
        format.html { render :new }
      end
    end
  end

  def update
    @product = set_attributes_languages(@product, ['name', 'description'])

    respond_to do |format|
      if @product.update(product_params)
        format.html { redirect_to edit_admin_product_path(@product), notice: 'Product was successfully updated.' }
      else
        format.html { render :edit }
      end
    end
  end

  def destroy
    @product.destroy
    respond_to do |format|
      format.html { redirect_to admin_root_path, notice: 'Product was successfully destroyed.' }
    end
  end

  def management

  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_product
      @product = Product.find(params[:id])
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def product_params
      params.fetch(:product, {}).permit(
        :name,
        :description,
        :active,
        :type_calculation_id,
        :subcategory_id,
        :image,
        :video
      )
    end
end