require 'rails_helper'

RSpec.describe Admin::ProductBlocksController, type: :controller do

  let(:valid_attributes) {
    FactoryGirl.attributes_for(:product_block_m2).merge({ product_id: create(:product_m2).id })
  }

  let(:invalid_attributes) { { size_x: '2500' } }

  let(:valid_session) { {} }

  describe "POST #create" do
    context "with valid params" do
      it "creates a new ProductBlock" do
        expect {
          post :create, params: {product_block: valid_attributes}, session: valid_session
        }.to change(ProductBlock, :count).by(1)
      end

      it "assigns a newly created product_block as @product_block" do
        post :create, params: {product_block: valid_attributes}, session: valid_session
        expect(assigns(:product_block)).to be_a(ProductBlock)
        expect(assigns(:product_block)).to be_persisted
      end

    end

    context "with invalid params" do
      it "assigns a newly created but unsaved product_block as @product_block" do
        post :create, params: {product_block: invalid_attributes}, session: valid_session
        expect(assigns(:product_block)).to be_a_new(ProductBlock)
      end
    end
  end

  describe "PUT #update" do
    context "with valid params" do

      let(:new_attributes) { { size_x: 1000 } }

      it "updates the requested product_block" do
        product_block = ProductBlock.create! valid_attributes
        put :update, params: {id: product_block.to_param, product_block: new_attributes}, session: valid_session
        product_block.reload
        expect(ProductBlock.last.size_x).to eq new_attributes[:size_x]
      end

      it "assigns the requested product_block as @product_block" do
        product_block = ProductBlock.create! valid_attributes
        put :update, params: {id: product_block.to_param, product_block: valid_attributes}, session: valid_session
        expect(assigns(:product_block)).to eq(product_block)
      end
    end

    context "with invalid params" do
      it "assigns the product_block as @product_block" do
        product_block = ProductBlock.create! valid_attributes
        put :update, params: {id: product_block.to_param, product_block: invalid_attributes}, session: valid_session
        expect(assigns(:product_block)).to eq(product_block)
      end
    end
  end

  describe "DELETE #destroy" do
    it "destroys the requested product_block" do
      product_block = ProductBlock.create! valid_attributes
      expect {
        delete :destroy, params: {id: product_block.to_param}, session: valid_session
      }.to change(ProductBlock, :count).by(-1)
    end
  end
end
