require 'rails_helper'

RSpec.describe Admin::SubcategoriesController, type: :controller do

  let(:valid_attributes) {
    FactoryGirl.attributes_for(:subcategory).merge({ category_id: create(:category).id })
  }

  let(:invalid_attributes) { { name_catalan: nil } }

  let(:valid_session) { {} }

  describe "GET #index" do
    it "assigns all subcategories as @subcategories" do
      subcategory = Subcategory.create! valid_attributes
      get :index, params: {}, session: valid_session
      expect(assigns(:subcategories)).to eq([subcategory])
    end
  end

  describe "GET #new" do
    it "assigns a new subcategory as @subcategory" do
      get :new, params: {}, session: valid_session
      expect(assigns(:subcategory)).to be_a_new(Subcategory)
    end
  end

  describe "GET #edit" do
    it "assigns the requested subcategory as @subcategory" do
      subcategory = Subcategory.create! valid_attributes
      get :edit, params: {id: subcategory.to_param}, session: valid_session
      expect(assigns(:subcategory)).to eq(subcategory)
    end
  end

  describe "POST #create" do
    context "with valid params" do
      it "creates a new Subcategory" do
        expect {
          post :create, params: {subcategory: valid_attributes}, session: valid_session
        }.to change(Subcategory, :count).by(1)
      end

      it "assigns a newly created subcategory as @subcategory" do
        post :create, params: {subcategory: valid_attributes}, session: valid_session
        expect(assigns(:subcategory)).to be_a(Subcategory)
        expect(assigns(:subcategory)).to be_persisted
      end

      it "redirects to the created subcategory" do
        post :create, params: {subcategory: valid_attributes}, session: valid_session
        expect(response).to redirect_to(admin_subcategories_path)
      end
    end

    context "with invalid params" do
      it "assigns a newly created but unsaved subcategory as @subcategory" do
        post :create, params: {subcategory: invalid_attributes}, session: valid_session
        expect(assigns(:subcategory)).to be_a_new(Subcategory)
      end

      it "re-renders the 'new' template" do
        post :create, params: {subcategory: invalid_attributes}, session: valid_session
        expect(response).to render_template("new")
      end
    end
  end

  describe "PUT #update" do
    context "with valid params" do

      let(:new_attributes) { { name_catalan: 'b' } }

      it "updates the requested subcategory" do
        subcategory = Subcategory.create! valid_attributes
        put :update, params: {id: subcategory.to_param, subcategory: new_attributes}, session: valid_session
        subcategory.reload
        expect(Subcategory.last.name_catalan).to eq new_attributes[:name_catalan]
      end

      it "assigns the requested subcategory as @subcategory" do
        subcategory = Subcategory.create! valid_attributes
        put :update, params: {id: subcategory.to_param, subcategory: valid_attributes}, session: valid_session
        expect(assigns(:subcategory)).to eq(subcategory)
      end

      it "redirects to the subcategory" do
        subcategory = Subcategory.create! valid_attributes
        put :update, params: {id: subcategory.to_param, subcategory: valid_attributes}, session: valid_session
        expect(response).to redirect_to(admin_subcategories_path)
      end
    end

    context "with invalid params" do
      it "assigns the subcategory as @subcategory" do
        subcategory = Subcategory.create! valid_attributes
        put :update, params: {id: subcategory.to_param, subcategory: invalid_attributes}, session: valid_session
        expect(assigns(:subcategory)).to eq(subcategory)
      end

      it "re-renders the 'edit' template" do
        subcategory = Subcategory.create! valid_attributes
        put :update, params: {id: subcategory.to_param, subcategory: invalid_attributes}, session: valid_session
        expect(response).to render_template("edit")
      end
    end
  end

  describe "DELETE #destroy" do
    it "destroys the requested subcategory" do
      subcategory = Subcategory.create! valid_attributes
      expect {
        delete :destroy, params: {id: subcategory.to_param}, session: valid_session
      }.to change(Subcategory, :count).by(-1)
    end

    it "redirects to the subcategories list" do
      subcategory = Subcategory.create! valid_attributes
      delete :destroy, params: {id: subcategory.to_param}, session: valid_session
      expect(response).to redirect_to(admin_subcategories_path)
    end
  end

end
